"use client"

import { useState } from "react"
import Link from "next/link"
import { ArrowLeft, BookOpen, ChevronRight, Search } from "lucide-react"
import Quiz from "@/components/quiz"
import NavBar from "@/components/nav-bar"

// Définition des types
type Chapter = {
  id: string
  title: string
  description: string
  questionCount: number
  code: string
  color: "red" | "blue" | "yellow" | "green"
}

type QuizQuestion = {
  qid: string
  question: string
  correct_answer: string
  explanation: string
  image_url: string
  suggestion: string[]
}

// Liste des chapitres disponibles
const chapters: Chapter[] = [
  {
    id: "76",
    title: "La vitesse maximale",
    description: "Questions sur les limitations de vitesse en fonction des zones et des conditions.",
    questionCount: 15,
    code: "la vitesse maximale_76",
    color: "red",
  },
  {
    id: "73",
    title: "La voiture",
    description: "Questions sur les équipements obligatoires et l'entretien du véhicule.",
    questionCount: 12,
    code: "la voiture_73",
    color: "blue",
  },
  {
    id: "72",
    title: "Les conducteurs",
    description: "Questions sur les règles concernant les conducteurs et le permis de conduire.",
    questionCount: 18,
    code: "les conducteurs_72",
    color: "green",
  },
  {
    id: "65",
    title: "La signalisation",
    description: "Questions sur les panneaux et les marquages au sol.",
    questionCount: 20,
    code: "la signalisation_65",
    color: "blue",
  },
  {
    id: "54",
    title: "Les priorités",
    description: "Questions sur les règles de priorité dans différentes situations.",
    questionCount: 14,
    code: "les priorités_54",
    color: "yellow",
  },
  {
    id: "48",
    title: "L'autoroute",
    description: "Questions sur les règles spécifiques à la conduite sur autoroute.",
    questionCount: 10,
    code: "l'autoroute_48",
    color: "green",
  },
  {
    id: "42",
    title: "Le stationnement",
    description: "Questions sur les règles de stationnement et d'arrêt.",
    questionCount: 16,
    code: "le stationnement_42",
    color: "blue",
  },
  {
    id: "36",
    title: "L'alcool et la conduite",
    description: "Questions sur les effets de l'alcool et les sanctions encourues.",
    questionCount: 8,
    code: "l'alcool et la conduite_36",
    color: "red",
  },
]

// Questions d'exemple pour chaque chapitre
const chapterQuestions: Record<string, QuizQuestion[]> = {
  "76": [
    {
      qid: "295",
      question:
        "Cette limite de vitesse s'applique...\n\nA. ... jusqu'au carrefour suivant.\nB. ... jusqu'à ce que vous voyez le panneau \"Fin de Zone\".",
      correct_answer: "a",
      explanation: "LEÇON 12 – 'La vitesse'. \nJusqu'au carrefour suivant.",
      image_url: "https://examen.gratisrijbewijsonline.be/afbeeldingen/197/295.jpg",
      suggestion: ["... jusqu'au carrefour suivant.", '... jusqu\'à ce que vous voyez le panneau "Fin de Zone".'],
    },
    {
      qid: "123",
      question: "Quelle est la vitesse maximale autorisée en agglomération ?",
      correct_answer: "a",
      explanation:
        "LEÇON 12 – 'La vitesse'. En agglomération, la vitesse est limitée à 50 km/h sauf indication contraire.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: ["50 km/h", "70 km/h", "90 km/h"],
    },
    {
      qid: "301",
      question:
        "Quelle est la vitesse maximale autorisée sur autoroute par temps de pluie pour un conducteur ayant son permis depuis plus de 3 ans ?",
      correct_answer: "b",
      explanation: "LEÇON 12 – 'La vitesse'. Sur autoroute, par temps de pluie, la vitesse est limitée à 110 km/h.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: ["90 km/h", "110 km/h", "130 km/h"],
    },
    {
      qid: "306",
      question: "Sur autoroute, quelle est la distance de sécurité minimale à respecter ?",
      correct_answer: "b",
      explanation:
        "LEÇON 12 – 'La vitesse'. Sur autoroute, il est recommandé de respecter une distance de sécurité d'au moins 2 secondes de trajet.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: ["1 seconde de trajet", "2 secondes de trajet", "3 secondes de trajet"],
    },
    {
      qid: "125",
      question:
        "Que devez-vous faire à l'approche d'un passage à niveau dont les barrières sont en train de s'abaisser ?",
      correct_answer: "b",
      explanation:
        "LEÇON 8 – 'Les passages à niveau'. Vous devez vous arrêter dès que les feux rouges clignotants s'allument ou que les barrières commencent à s'abaisser.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: [
        "Accélérer pour passer avant la fermeture complète",
        "Ralentir et vous arrêter avant les barrières",
        "Klaxonner pour que le garde-barrière vous laisse passer",
      ],
    },
  ],
  "73": [
    {
      qid: "124",
      question: "Dans quel cas le port de la ceinture de sécurité n'est pas obligatoire ?",
      correct_answer: "c",
      explanation:
        "LEÇON 5 – 'La sécurité'. Le port de la ceinture est obligatoire sauf si vous possédez un certificat médical d'exemption.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: [
        "Lorsque vous effectuez une marche arrière",
        "Lorsque vous conduisez en agglomération",
        "Lorsque vous possédez un certificat médical d'exemption",
        "Le port de la ceinture est toujours obligatoire",
      ],
    },
    {
      qid: "307",
      question: "Que faire en cas de crevaison sur autoroute ?",
      correct_answer: "b",
      explanation:
        "LEÇON 14 – 'Les situations d'urgence'. En cas de crevaison sur autoroute, il est recommandé de mettre le triangle de signalisation et d'appeler les secours plutôt que de changer la roue vous-même sur la bande d'arrêt d'urgence, ce qui est dangereux.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: [
        "Changer la roue sur la bande d'arrêt d'urgence",
        "Mettre le triangle de signalisation et appeler les secours",
        "Sortir à la prochaine aire de service si possible",
      ],
    },
    {
      qid: "955",
      question: "Pouvez vous circuler sur cet accotement pour croiser un vehicule ?",
      correct_answer: "oui",
      explanation:
        "LEÇON 7 – 'Les piétons'.\nIl ne peut pas sur une piste cyclable ou sur la bande à côté de la ligne imaginaire de la voie destinée au stationnement.",
      image_url: "https://examen.gratisrijbewijsonline.be/afbeeldingen/197/955.jpg",
      suggestion: ["oui", "non"],
    },
  ],
  "72": [
    {
      qid: "303",
      question: "Quel est le taux d'alcoolémie maximum autorisé pour un conducteur novice ?",
      correct_answer: "a",
      explanation:
        "LEÇON 13 – 'L'alcool et la conduite'. Pour un conducteur novice (moins de 3 ans de permis), le taux d'alcoolémie maximum est de 0,2 g/l de sang.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: ["0,2 g/l de sang", "0,5 g/l de sang", "0,8 g/l de sang"],
    },
    {
      qid: "308",
      question: "Quelle est la durée de validité d'un permis probatoire ?",
      correct_answer: "c",
      explanation: "LEÇON 1 – 'Le permis de conduire'. Le permis probatoire est valable pour une durée de 3 ans.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: ["1 an", "2 ans", "3 ans"],
    },
    {
      qid: "305",
      question: "Quand le feu est orange, vous devez :",
      correct_answer: "a",
      explanation:
        "LEÇON 3 – 'La signalisation'. Lorsque le feu est orange, vous devez vous arrêter si les conditions de sécurité le permettent.",
      image_url: "/placeholder.svg?height=300&width=400",
      suggestion: [
        "Vous arrêter si les conditions de sécurité le permettent",
        "Accélérer pour libérer l'intersection rapidement",
        "Ralentir et passer avec prudence",
      ],
    },
  ],
}

// Vérifiez que chaque ID de chapitre a des questions correspondantes
console.log("IDs de chapitres disponibles:", Object.keys(chapterQuestions))
console.log(
  "Chapitres disponibles:",
  chapters.map((c) => c.id),
)

// Assurez-vous que les questions sont correctement formatées
for (const [chapterId, questions] of Object.entries(chapterQuestions)) {
  if (!questions || questions.length === 0) {
    console.warn(`Le chapitre ${chapterId} n'a pas de questions`)
  }
}

export default function ExercisesPage() {
  const [view, setView] = useState<"chapters" | "quiz">("chapters")
  const [selectedChapter, setSelectedChapter] = useState<Chapter | null>(null)
  const [searchTerm, setSearchTerm] = useState("")

  const filteredChapters = chapters.filter(
    (chapter) =>
      chapter.title.toLowerCase().includes(searchTerm.toLowerCase()) ||
      chapter.code.toLowerCase().includes(searchTerm.toLowerCase()),
  )

  const handleChapterSelect = (chapter: Chapter) => {
    setSelectedChapter(chapter)
    // Vérifier si les questions existent pour ce chapitre
    if (chapterQuestions[chapter.id] && chapterQuestions[chapter.id].length > 0) {
      setView("quiz")
    } else {
      // Afficher un message d'erreur ou utiliser des questions par défaut
      console.error(`Aucune question trouvée pour le chapitre ${chapter.id}`)
      // Vous pouvez définir des questions par défaut ici si nécessaire
    }
  }

  const handleBackToChapters = () => {
    setView("chapters")
    setSelectedChapter(null)
  }

  if (view === "quiz" && selectedChapter) {
    const questions = chapterQuestions[selectedChapter.id] || []

    return (
      <div className="min-h-screen route-pattern">
        <NavBar />

        <div className="route-header">
          <div className="container mx-auto px-4">
            <button
              onClick={handleBackToChapters}
              className="flat-button bg-transparent text-[#007AFF] hover:bg-[#007AFF]/10 mb-2 flex items-center"
            >
              <ArrowLeft className="mr-2 h-4 w-4" />
              Retour aux chapitres
            </button>
            <h1 className="text-2xl font-bold text-[#007AFF]">Exercices: {selectedChapter.title}</h1>
            <div className="road-line"></div>
          </div>
        </div>
        {questions.length > 0 ? (
          <Quiz title={`Exercices: ${selectedChapter.title}`} questions={questions} type="exercise" />
        ) : (
          <div className="container mx-auto px-4 py-8 text-center">
            <p className="text-lg text-gray-600">
              Aucune question disponible pour ce chapitre. Veuillez essayer un autre chapitre.
            </p>
          </div>
        )}
      </div>
    )
  }

  return (
    <div className="min-h-screen route-pattern">
      <NavBar />

      {/* Reste du contenu de la page */}
      <div className="route-header">
        <div className="container mx-auto px-4">
          <h1 className="text-3xl font-bold text-center text-[#007AFF]">Exercices d'entraînement</h1>
          <div className="road-line"></div>
        </div>
      </div>

      <div className="container mx-auto px-4 py-8 max-w-4xl">
        <Link href="/" className="inline-flex items-center text-[#007AFF] mb-6 hover:underline">
          <ArrowLeft className="mr-2 h-4 w-4" />
          Retour à l'accueil
        </Link>

        <div className="mb-8">
          <p className="text-lg text-gray-600 mb-6">
            Sélectionnez un chapitre pour commencer les exercices. Chaque chapitre contient des questions spécifiques à
            un thème.
          </p>

          <div className="relative mb-6">
            <input
              type="text"
              placeholder="Rechercher un chapitre..."
              value={searchTerm}
              onChange={(e) => setSearchTerm(e.target.value)}
              className="flat-input w-full pl-10"
            />
            <Search className="h-5 w-5 absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400" />
          </div>
        </div>

        <div className="space-y-4">
          {filteredChapters.length === 0 ? (
            <div className="text-center py-8">
              <p className="text-gray-500">Aucun chapitre trouvé pour "{searchTerm}"</p>
            </div>
          ) : (
            filteredChapters.map((chapter) => {
              const colorMap = {
                red: "#FF3B30",
                blue: "#007AFF",
                yellow: "#FFCC00",
                green: "#34C759",
              }
              const color = colorMap[chapter.color]

              return (
                <div
                  key={chapter.id}
                  className="flat-card border-l-4 cursor-pointer"
                  style={{ borderLeftColor: color }}
                  onClick={() => handleChapterSelect(chapter)}
                >
                  <div className="flex items-start justify-between">
                    <div className="flex-1">
                      <div className="flex items-center mb-2">
                        <BookOpen className="h-5 w-5 mr-2" style={{ color }} />
                        <h3 className="text-xl font-bold">{chapter.title}</h3>
                      </div>
                      <p className="text-gray-600 mb-4">{chapter.description}</p>
                      <div className="flex justify-between items-center">
                        <div className="text-sm text-gray-500">Code: {chapter.code}</div>
                        <div
                          className="text-sm px-3 py-1 rounded-full"
                          style={{ backgroundColor: `${color}10`, color }}
                        >
                          {chapter.questionCount} questions
                        </div>
                      </div>
                    </div>
                    <div className="p-2 rounded-full" style={{ color }}>
                      <ChevronRight className="h-5 w-5" />
                    </div>
                  </div>
                </div>
              )
            })
          )}
        </div>
      </div>
    </div>
  )
}
